@@ -14,7 +14,7 @@ Log::Handler::Plugin::Config::Properties - Config loader for Config::Properties.
 
 Expect the config file name and returns the config as a reference.
 
-The configuration will be splitted by dot.
+The configuration uses full stops "." as a delimiter.
 
 =head1 CONFIG STYLE
 
@@ -28,7 +28,7 @@ The configuration will be splitted by dot.
     file.mylog.minlevel = warn
     file.mylog.filename = example.log
     file.mylog.newline = 1
-    file.mylog.prefix = '%T %H[%P] [%L] %S: '
+    file.mylog.message_layout = %T %H[%P] [%L] %S: %m
 
 =head1 PREREQUISITES
     
@@ -41,14 +41,16 @@ No exports.
 =head1 REPORT BUGS
     
 Please report all bugs to <jschulz.cpan(at)bloonix.de>.
-    
+
+If you send me a mail then add Log::Handler into the subject.
+
 =head1 AUTHOR
 
 Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -61,7 +63,8 @@ use strict;
 use warnings;
 use Config::Properties;
 
-our $VERSION = '0.00_06';
+our $VERSION = '0.04';
+our $SPLITTOTREE = qr/\./;
 
 sub get_config {
     my ($class, $config_file) = @_;
@@ -71,7 +74,7 @@ sub get_config {
     $properties->load($fh);
     close $fh;
 
-    my $config = $properties->splitToTree(qr/\./);
+    my $config = $properties->splitToTree($SPLITTOTREE);
     return $config;
 }
 
